# Xebus RESTful API Client Python Library 

Xebus RESTful API Client Python Library is a repository of
classes that provide Pythonic interfaces to the Xebus RESTful RESTful API server.

This library requires:

* Xebus Common Python Library
* Perseus Common Python Library
* Perseus RESTful API Client Python Library
